import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';

import '../../../models/statistics.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';

class Statistics extends StatelessWidget {
  const Statistics({super.key});

  @override
  Widget build(BuildContext context) {
    late Future<StatisticsData> futureAlbum = ScrobblesApi.fetchStatistics();

    return FutureBuilder<StatisticsData>(
      future: futureAlbum,
      builder: (context, snapshot) {
        if (snapshot.hasData) {
          final TextTheme textTheme = Theme.of(context).primaryTextTheme;

          return Card(
            elevation: 2,
            shadowColor: Theme.of(context).colorScheme.shadow,
            color: Theme.of(context).colorScheme.primary,
            shape: const RoundedRectangleBorder(
                borderRadius: BorderRadius.all(Radius.circular(12))),
            child: Padding(
              padding: const EdgeInsets.all(12.0),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Text(
                    tr('global_statistics'),
                    style: textTheme.titleLarge!.apply(fontWeightDelta: 2),
                  ),
                  Text(
                    tr('statistics_total_scrobbles_count') +
                        ' ' +
                        snapshot.data!.totalCount.toString(),
                    style: textTheme.bodyMedium,
                  ),
                  Text(
                    tr('statistics_last_scrobble') +
                        ' ' +
                        DateFormat().format(snapshot.data!.lastScrobble),
                    style: textTheme.bodyMedium,
                  ),
                  Text(
                    'statistics_selected_period',
                    style: textTheme.bodyMedium,
                  ).tr(namedArgs: {'daysCount': snapshot.data!.selectedPeriod.toString()}),
                  Text(
                    tr('statistics_recent_scrobbles_count') +
                        ' ' +
                        snapshot.data!.recentCount.toString(),
                    style: textTheme.bodyMedium,
                  ),
                  Text(
                    tr('statistics_discoveries') +
                        ' ' +
                        snapshot.data!.firstPlayedArtistsCount.toString() +
                        ' ' +
                        tr('statistics_discoveries_artists') +
                        ' / ' +
                        snapshot.data!.firstPlayedTracksCount.toString() +
                        ' ' +
                        tr('statistics_discoveries_tracks'),
                    style: textTheme.bodyMedium,
                  ),
                ],
              ),
            ),
          );
        } else if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return const CircularProgressIndicator();
      },
    );
  }
}
